import { SignService } from '../../service/platform/sign.service';
import { CVO_sign, FVO_sign, QVO_sign, UVAO_sign } from '../../interface/platform/sign.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { Controller, Inject, Get, Param, Post, Body, Del, Query } from '@midwayjs/core';
import { omit, pick } from 'lodash';
import { ServiceError, ErrorCode } from '../../error/service.error';
import { BaseController } from '../../frame/BaseController';
@ApiTags(['赛事报名表'])
@Controller('/sign')
export class SignController implements BaseController {
  @Inject()
  service: SignService;

  @Get('/')
  @ApiTags('列表查询')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_sign })
  async index(@Query() query: object) {
    const qobj = omit(query, ['skip', 'limit']);
    const others = pick(query, ['skip', 'limit']);
    const qbr = this.service.queryBuilder(qobj);
    const result = await this.service.query(qbr, others);
    return result;
  }

  @Get('/:id')
  @ApiTags('单查询')
  @ApiResponse({ type: FVO_sign })
  async fetch(@Param('id') id: number) {
    const qbr = this.service.queryBuilder({ id });
    const data = await this.service.fetch(qbr);
    const result = new FVO_sign(data);
    return result;
  }

  @Post('/')
  @ApiTags('创建数据')
  @Validate()
  @ApiResponse({ type: CVO_sign })
  async create(@Body() data: object) {
    const dbData = await this.service.create(data);
    const result = new CVO_sign(dbData);
    return result;
  }

  @Post('/:id')
  @ApiTags('修改数据')
  @Validate()
  @ApiResponse({ type: UVAO_sign })
  async update(@Param('id') id: number, @Body() data: object) {
    if (!id) throw new ServiceError(ErrorCode.ID_NOT_FOUND);
    const result = await this.service.update({ id }, data);
    return result;
  }

  @Del('/:id')
  @ApiTags('删除数据')
  @Validate()
  async delete(@Param('id') id: number) {
    if (!id) throw new ServiceError(ErrorCode.ID_NOT_FOUND);
    const result = await this.service.delete({ id });
    return result;
  }
  @Get('/sign')
  async sign(@Query() filter) {
    const list = await this.service.sign(filter);
    return list;
  }
}
