import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/core';
import { omit, pick } from 'lodash';
import { ApiResponse, ApiTags } from '@midwayjs/swagger';
import { BaseController } from '../../frame/BaseController';
import { ErrorCode, ServiceError } from '../../error/service.error';
import { Validate } from '@midwayjs/validate';
import { RoleService } from '../../service/system/role.service';
import { CVO_role, FVO_role, QVO_role, UVAO_role } from '../../interface/system/role.interface';
import { MenusService } from '../../service/system/menus.service';

@ApiTags(['角色表'])
@Controller('/role')
export class RoleController implements BaseController {
  controllerCode = 'system_role';
  @Inject()
  service: RoleService;
  @Inject()
  menusService: MenusService;

  @Get('/')
  @ApiTags('列表查询')
  @ApiResponse({ type: QVO_role })
  async index(@Query() query: object) {
    const qobj = omit(query, ['skip', 'limit']);
    const others = pick(query, ['skip', 'limit']);
    const qbr = this.service.queryBuilder(qobj);
    const { data, total } = await this.service.query(qbr, others);
    const list = [];
    for (const i of data) {
      const newData = new QVO_role(i);
      list.push(newData);
    }
    return { data: list, total };
  }

  @Get('/:id')
  @ApiTags('单查询')
  @ApiResponse({ type: FVO_role })
  async fetch(@Param('id') id: number) {
    const qbr = this.service.queryBuilder({ id });
    const data = await this.service.fetch(qbr);
    const result = new FVO_role(data);
    return result;
  }

  @Post('/')
  @ApiTags('创建数据')
  @Validate()
  @ApiResponse({ type: CVO_role })
  async create(@Body() data: object) {
    const dbData = await this.service.create(data);
    const result = new CVO_role(dbData);
    return result;
  }

  @Post('/:id')
  @ApiTags('修改数据')
  @Validate()
  @ApiResponse({ type: UVAO_role })
  async update(@Param('id') id: number, @Body() data: object) {
    if (!id) throw new ServiceError(ErrorCode.ID_NOT_FOUND);
    const result = await this.service.update({ id }, data);
    return result;
  }

  @Del('/:id')
  @ApiTags('删除数据')
  @Validate()
  async delete(@Param('id') id: number) {
    const result = await this.service.delete({ id });
    return result;
  }
}
