import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/core';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../../service/util.service';
import { BaseController } from '../../frame/BaseController';
import { omit, pick } from 'lodash';
import { ErrorCode, ServiceError } from '../../error/service.error';
import { Context } from '@midwayjs/koa';
import { InvestmentService } from '../../service/users/investment.service';
import { QVO_state, FVO_state, CVO_state, UVAO_state } from '../../interface/users/state.interface';
@ApiTags(['政府部门'])
@Controller('/state')
export class StateController implements BaseController {
  @Inject()
  service: InvestmentService;
  @Inject()
  ctx: Context;

  @Inject()
  utilService: UtilService;

  @Get('/')
  @ApiTags('列表查询')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_state })
  async index(@Query() query: object) {
    const qobj = omit(query, ['skip', 'limit']);
    const others = pick(query, ['skip', 'limit']);
    const qbr = this.service.queryBuilder(qobj);
    const result = await this.service.query(qbr, others);
    return result;
  }

  @Get('/:id')
  @ApiTags('单查询')
  @ApiResponse({ type: FVO_state })
  async fetch(@Param('id') id: number) {
    const qbr = this.service.queryBuilder({ id });
    const data = await this.service.fetch(qbr);
    const result = new FVO_state(data);
    return result;
  }

  @Post('/')
  @ApiTags('创建数据')
  @Validate()
  @ApiResponse({ type: CVO_state })
  async create(@Body() data: object) {
    const dbData = await this.service.create(data);
    const result = new CVO_state(dbData);
    return result;
  }

  @Post('/:id')
  @ApiTags('修改数据')
  @Validate()
  @ApiResponse({ type: UVAO_state })
  async update(@Param('id') id: number, @Body() data: object) {
    if (!id) throw new ServiceError(ErrorCode.ID_NOT_FOUND);
    const result = await this.service.update({ id }, data);
    await this.utilService.updateUserAfter(id, data, 'Association');
    return result;
  }

  @Del('/:id')
  @ApiTags('删除数据')
  @Validate()
  async delete(@Param('id') id: number) {
    if (!id) throw new ServiceError(ErrorCode.ID_NOT_FOUND);
    const result = await this.service.delete({ id });
    return result;
  }
}
